@@ -6,7 +6,7 @@
 ;; Maintainer: Tassilo Horn <tsdh@gnu.org>
 ;; Keywords: minibuffer completion
 ;; Package-Requires: ((emacs "27.1"))
-;; Version: 1.1
+;; Version: 1.3
 
 ;; This file is part of GNU Emacs.
 
@@ -31,10 +31,8 @@
 ;; using the standard completion help (unless the number of possible
 ;; completions exceeds `aggressive-completion-max-shown-completions').
 ;;
-;; Automatic completion is temporarily disabled after all commands in
-;; `aggressive-completion-no-complete-commands'.  Basically all deletion/kill
-;; commands are listed here in order not to complete back to the thing you just
-;; deleted.
+;; Automatic completion is done after all commands in
+;; `aggressive-completion-auto-complete-commands'.
 ;;
 ;; Aggressive completion can be toggled using
 ;; `aggressive-completion-toggle-auto-complete' (bound to `M-t' by default)
@@ -70,19 +68,16 @@ If nil, only show the completion help."
   "Maximum number of possible completions for showing completion help."
   :type 'integer)
 
-(defcustom aggressive-completion-no-complete-commands
-  '( left-char icomplete-fido-backward-updir minibuffer-complete
-     right-char delete-backward-char backward-kill-word
-     backward-kill-paragraph backward-kill-sentence backward-kill-sexp
-     delete-char kill-word kill-line completion-at-point
-     move-beginning-of-line left-word)
-  "Commands after which automatic completion is not performed."
-  :type '(repeat command))
+(defcustom aggressive-completion-auto-complete-commands
+  '( self-insert-command yank)
+  "Commands after which automatic completion is performed."
+  :type '(repeat function))
 
 (defvar aggressive-completion--timer nil)
 
 (defun aggressive-completion--do ()
   "Perform aggressive completion."
+  (message "last-command: %S" last-command)
   (when (window-minibuffer-p)
     (let* ((completions (completion-all-sorted-completions))
            ;; Don't ding if there are no completions, etc.
@@ -98,19 +93,23 @@ If nil, only show the completion help."
           (cl-incf i))
         (if (and (> i 0)
                  (< i aggressive-completion-max-shown-completions))
-            (if (or (null aggressive-completion-auto-complete)
-                    (memq last-command
-                          aggressive-completion-no-complete-commands))
-                ;; This ensures we still can repeatedly hit TAB to scroll
-                ;; through the list of completions.
-                (unless (and (= last-command-event ?\t)
-                             (window-live-p
-                              (get-buffer-window "*Completions*"))
-                             (with-current-buffer "*Completions*"
-                               (> (point) (point-min))))
-                  (minibuffer-completion-help))
-              (minibuffer-complete)
-              (unless (window-live-p (get-buffer-window "*Completions*"))
+            (if (and aggressive-completion-auto-complete
+                     (memq last-command
+                           aggressive-completion-auto-complete-commands))
+                ;; Perform automatic completion.
+                (progn
+                  (minibuffer-complete)
+                  (unless (window-live-p (get-buffer-window "*Completions*"))
+                    (minibuffer-completion-help)))
+              ;; Only show the completion help.  This slightly awkward
+              ;; condition ensures we still can repeatedly hit TAB to scroll
+              ;; through the list of completions.
+              (unless (and (memq last-command
+                                 '(completion-at-point minibuffer-complete))
+                           (window-live-p
+                            (get-buffer-window "*Completions*"))
+                           (with-current-buffer "*Completions*"
+                             (> (point) (point-min))))
                 (minibuffer-completion-help)))
           ;; Close the *Completions* buffer if there are too many
           ;; or zero completions.
